@@ -41,7 +41,7 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
   # obtain ps estimation
   # estimate with formula
   if(is.null(ps.estimate)){
-    fit<-do.call(PSmethod,c(list(ps.formula = ps.formula, method=ps.method, data=data_p,ncate=2),ps.control=ps.control))
+    fit<-do.call(PSmethod,list(ps.formula = ps.formula, method=ps.method, data=data_p,ncate=2,ps.control=ps.control))
     W<- model.matrix(ps.formula,data_p)                      # design matrix
 
     e.h <- as.numeric(fit$e.h[,2])
@@ -84,10 +84,10 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
       XY<-model.matrix(formula(out.formula),data=dataaug)
 
       #predict outcome
-      fitout0<-do.call(OUTmethod,c(list(out.formula=out.formula,y=y[z==0], out.method=out.method, family=family, datain=dataaug0, dataout=dataaug),out.control=out.control))
+      fitout0<-do.call(OUTmethod,list(out.formula=out.formula,y=y[z==0], out.method=out.method, family=family, datain=dataaug0, dataout=dataaug,out.control=out.control))
       m0.h<-fitout0$m.est
       gamma0.h<-fitout0$gamma.h
-      fitout1<-do.call(OUTmethod,c(list(out.formula=out.formula,y=y[z==1], out.method=out.method, family=family, datain=dataaug1, dataout=dataaug),out.control=out.control))
+      fitout1<-do.call(OUTmethod,list(out.formula=out.formula,y=y[z==1], out.method=out.method, family=family, datain=dataaug1, dataout=dataaug,out.control=out.control))
       m1.h<-fitout1$m.est
       gamma1.h<-fitout1$gamma.h
 
@@ -135,7 +135,7 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
           conser<-0 #is pd
         },error = function(w) {
           warning("The sandwich matrix not pd, therefore not invertable, use conservative variance instead, please double check")
-           })
+        })
       }
 
       #use conservative
@@ -161,7 +161,7 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
         y.b<-y[samp.b]
         z.b<-z[samp.b]
 
-        fit.b<-do.call(PSmethod,c(list(ps.formula = ps.formula, method=ps.method, data=data.b,ncate=2),ps.control))
+        fit.b<-do.call(PSmethod,list(ps.formula = ps.formula, method=ps.method, data=data.b,ncate=2,ps.control=ps.control))
         e.b <- as.numeric(fit.b$e.h[,2])
 
         if(weight=="entropy"){
@@ -203,7 +203,7 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
           conser<-0 #is pd
         },error = function(w) {
           warning("The sandwich matrix not pd, therefore not invertable, use conservative variance instead, please double check")
-          })
+        })
 
       }else if(!is.null(ps.estimate) & is.null(out.estimate)){
 
@@ -229,6 +229,8 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
         })
       }
 
+
+
       #if not pd then use conservative
       if(conser==1){
         theta.h<-augest[1:6]
@@ -253,7 +255,7 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
         data.b<-data_p[samp.b,]
         y.b<-y[samp.b]
         z.b<-z[samp.b]
-        fit.b<-do.call(PSmethod,c(list(ps.formula = ps.formula, method=ps.method, data=data.b,ncate=2),ps.control))
+        fit.b<-do.call(PSmethod,list(ps.formula = ps.formula, method=ps.method, data=data.b,ncate=2,ps.control=ps.control))
         e.b <- as.numeric(fit.b$e.h[,2])
 
         if(weight=="entropy"){
@@ -267,9 +269,9 @@ binest<-function(ps.formula=NULL,ps.estimate=NULL,zname=NULL,yname,data,trtgrp=N
         dataaug1.b<-dataaug.b[z.b==1,]
 
         #predict outcome
-        fitout0.b<-do.call(OUTmethod,c(list(out.formula=out.formula,y=y.b[z.b==0], out.method=out.method, family=family, datain=dataaug0.b, dataout=dataaug.b),out.control=out.control))
+        fitout0.b<-do.call(OUTmethod,list(out.formula=out.formula,y=y.b[z.b==0], out.method=out.method, family=family, datain=dataaug0.b, dataout=dataaug.b,out.control=out.control))
         m0.b<-fitout0.b$m.est
-        fitout1.b<-do.call(OUTmethod,c(list(out.formula=out.formula,y=y.b[z.b==1], out.method=out.method, family=family, datain=dataaug1.b, dataout=dataaug.b),out.control=out.control))
+        fitout1.b<-do.call(OUTmethod,list(out.formula=out.formula,y=y.b[z.b==1], out.method=out.method, family=family, datain=dataaug1.b, dataout=dataaug.b,out.control=out.control))
         m1.b<-fitout1.b$m.est
 
         mu.b <- ptbin(e.b,z.b,y.b,ftilt,m0.b,m1.b)
